# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'error_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.13.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ErrorDialog(object):
    def setupUi(self, ErrorDialog):
        ErrorDialog.setObjectName("ErrorDialog")
        ErrorDialog.resize(622, 114)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/error.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        ErrorDialog.setWindowIcon(icon)
        ErrorDialog.setSizeGripEnabled(True)
        self.layout = QtWidgets.QVBoxLayout(ErrorDialog)
        self.layout.setObjectName("layout")
        self.error_message = QtWidgets.QLabel(ErrorDialog)
        self.error_message.setText("")
        self.error_message.setObjectName("error_message")
        self.layout.addWidget(self.error_message)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.layout.addItem(spacerItem)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.copy_to_clipboard_btn = QtWidgets.QPushButton(ErrorDialog)
        self.copy_to_clipboard_btn.setObjectName("copy_to_clipboard_btn")
        self.horizontalLayout.addWidget(self.copy_to_clipboard_btn)
        self.layout.addLayout(self.horizontalLayout)

        self.retranslateUi(ErrorDialog)
        QtCore.QMetaObject.connectSlotsByName(ErrorDialog)

    def retranslateUi(self, ErrorDialog):
        _translate = QtCore.QCoreApplication.translate
        ErrorDialog.setWindowTitle(_translate("ErrorDialog", "Dialog"))
        self.copy_to_clipboard_btn.setText(_translate("ErrorDialog", "Copy to clipboard"))
from . import resource_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'd:\DSUsers\uidn3651\02__PythonWorkspace\asammdf\asammdf\gui\ui\values_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_RangeDialog(object):
    def setupUi(self, RangeDialog):
        RangeDialog.setObjectName("RangeDialog")
        RangeDialog.resize(697, 379)
        RangeDialog.setSizeGripEnabled(True)
        RangeDialog.setModal(True)
        self.gridLayout = QtWidgets.QGridLayout(RangeDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.reset_btn = QtWidgets.QPushButton(RangeDialog)
        self.reset_btn.setObjectName("reset_btn")
        self.gridLayout.addWidget(self.reset_btn, 0, 1, 1, 1)
        self.cancel_btn = QtWidgets.QPushButton(RangeDialog)
        self.cancel_btn.setObjectName("cancel_btn")
        self.gridLayout.addWidget(self.cancel_btn, 3, 1, 1, 1)
        self.apply_btn = QtWidgets.QPushButton(RangeDialog)
        self.apply_btn.setObjectName("apply_btn")
        self.gridLayout.addWidget(self.apply_btn, 2, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(
            20, 271, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.gridLayout.addItem(spacerItem, 1, 1, 1, 1)
        self.table = QtWidgets.QTableWidget(RangeDialog)
        self.table.setRowCount(100)
        self.table.setColumnCount(4)
        self.table.setObjectName("table")
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(3, item)
        self.table.horizontalHeader().setDefaultSectionSize(150)
        self.table.horizontalHeader().setMinimumSectionSize(30)
        self.table.horizontalHeader().setStretchLastSection(True)
        self.gridLayout.addWidget(self.table, 0, 0, 4, 1)
        self.gridLayout.setColumnStretch(0, 1)

        self.retranslateUi(RangeDialog)
        QtCore.QMetaObject.connectSlotsByName(RangeDialog)
        RangeDialog.setTabOrder(self.table, self.apply_btn)
        RangeDialog.setTabOrder(self.apply_btn, self.reset_btn)
        RangeDialog.setTabOrder(self.reset_btn, self.cancel_btn)

    def retranslateUi(self, RangeDialog):
        _translate = QtCore.QCoreApplication.translate
        RangeDialog.setWindowTitle(_translate("RangeDialog", "Edit value range colors"))
        self.reset_btn.setText(_translate("RangeDialog", "Reset"))
        self.cancel_btn.setText(_translate("RangeDialog", "Cancel"))
        self.apply_btn.setText(_translate("RangeDialog", "Apply"))
        item = self.table.horizontalHeaderItem(0)
        item.setText(_translate("RangeDialog", "From"))
        item = self.table.horizontalHeaderItem(1)
        item.setText(_translate("RangeDialog", "To"))
        item = self.table.horizontalHeaderItem(2)
        item.setText(_translate("RangeDialog", "Set color"))



# -*- coding: utf-8 -*-

import pyqtgraph as pg
import numpy as np


class FormatedAxis(pg.AxisItem):
    def __init__(self, *args, **kwargs):

        super().__init__(*args, **kwargs)

        self.format = "phys"
        self.text_conversion = None

    def tickStrings(self, values, scale, spacing):
        strns = []

        if self.format == "phys":
            strns = super(FormatedAxis, self).tickStrings(values, scale, spacing)
            if self.text_conversion:
                strns = []
                for val in values:
                    nv = self.text_conversion.convert(np.array([val]))[0]
                    if isinstance(nv, bytes):
                        try:
                            strns.append(f'{val}={nv.decode("utf-8")}')
                        except:
                            strns.append(f'{val}={nv.decode("latin-1")}')
                    else:
                        strns.append(f"{val:.6f}")

        elif self.format == "hex":
            for val in values:
                val = float(val)
                if val.is_integer():
                    val = hex(int(val))
                else:
                    val = ""
                strns.append(val)

        elif self.format == "bin":
            for val in values:
                val = float(val)
                if val.is_integer():
                    val = bin(int(val))
                else:
                    val = ""
                strns.append(val)

        return strns

    def setLabel(self, text=None, units=None, unitPrefix=None, **args):
        """ overwrites pyqtgraph setLabel

        """
        show_label = False
        if text is not None:
            self.labelText = text
            show_label = True
        if units is not None:
            self.labelUnits = units
            show_label = True
        if show_label:
            self.showLabel()
        if unitPrefix is not None:
            self.labelUnitPrefix = unitPrefix
        if len(args) > 0:
            self.labelStyle = args
        self.label.setHtml(self.labelString())
        self._adjustSize()
        self.picture = None
        self.update()



# -*- coding: utf-8 -*-

import numpy as np

from ...signal import Signal as AsamSignal
from ..ui import resource_rc as resource_rc
from ..ui.define_channel_dialog import Ui_ComputedChannel
from PyQt5 import QtWidgets


OPS_TO_STR = {
    "+": "__add__",
    "-": "__sub__",
    "/": "__div__",
    "//": "__floordiv__",
    "*": "__mul__",
    "%": "__mod__",
    "**": "__pow__",
    "^": "__xor__",
    ">>": "__rshift__",
    "<<": "__lsift__",
    "&": "__and__",
    "|": "__or__",
}


class DefineChannel(Ui_ComputedChannel, QtWidgets.QDialog):
    def __init__(self, channels, all_timebase, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.setupUi(self)

        self.channels = {ch.name: ch for ch in channels}
        self.result = None
        self.pressed_button = None

        self.op1_type = None
        self.op1_value = None
        self.op2_type = None
        self.op2_value = None

        self.func_arg1 = None
        self.func_arg2 = None

        self.operand1.addItems(sorted(self.channels))
        self.operand1.insertItem(0, "CONSTANT")
        self.operand1.setCurrentIndex(-1)

        self.operand2.addItems(sorted(self.channels))
        self.operand2.insertItem(0, "CONSTANT")
        self.operand2.setCurrentIndex(-1)
        self.all_timebase = all_timebase

        self.op.addItems(
            [
                "+ (add)",
                "- (substract)",
                "/ (divide)",
                "// (floor divide)",
                "* (multiply)",
                "% (modulo)",
                "** (power)",
                "^ (xor)",
                "& (and)",
                "| (or)",
                ">> (right shift)",
                "<< (left shift)",
            ]
        )

        self.function.addItems(
            sorted(
                [
                    "arccos",
                    "arcsin",
                    "arctan",
                    "cos",
                    "deg2rad",
                    "degrees",
                    "rad2deg",
                    "radians",
                    "sin",
                    "tan",
                    "ceil",
                    "floor",
                    "rint",
                    "around",
                    "fix",
                    "trunc",
                    "cumprod",
                    "cumsum",
                    "diff",
                    "gradient",
                    "exp",
                    "log10",
                    "log",
                    "log2",
                    "absolute",
                    "cbrt",
                    "clip",
                    "sqrt",
                    "square",
                ]
            )
        )
        self.function.setCurrentIndex(-1)
        self.channel.addItems(sorted(self.channels))
        self.channel.setCurrentIndex(-1)

        self.apply_btn.clicked.connect(self.apply)
        self.cancel_btn.clicked.connect(self.cancel)
        self.operand1.currentIndexChanged.connect(self.op1_changed)
        self.operand2.currentIndexChanged.connect(self.op2_changed)

        self.apply_function_btn.clicked.connect(self.apply_function)
        self.function.currentIndexChanged.connect(self.function_changed)

    def op1_changed(self, index):
        if self.operand1.currentText() == "CONSTANT":
            self.op1_type = QtWidgets.QComboBox()
            self.op1_type.addItems(["int", "float"])
            self.op1_type.setCurrentIndex(-1)
            self.op1_type.currentIndexChanged.connect(self.op1_constant_changed)

            self.gridLayout.addWidget(self.op1_type, 0, 2)

        else:
            if self.op1_value is not None:
                self.op1_value.setParent(None)
                self.op1_value = None
            if self.op1_type is not None:
                self.op1_type.setParent(None)
                self.op1_type = None

    def op2_changed(self, index):
        if self.operand2.currentText() == "CONSTANT":
            self.op2_type = QtWidgets.QComboBox()
            self.op2_type.addItems(["int", "float"])
            self.op2_type.setCurrentIndex(-1)
            self.op2_type.currentIndexChanged.connect(self.op2_constant_changed)

            self.gridLayout.addWidget(self.op2_type, 2, 2)

        else:
            if self.op2_value is not None:
                self.op2_value.setParent(None)
                self.op2_value = None
            if self.op2_type is not None:
                self.op2_type.setParent(None)
                self.op2_type = None

    def op1_constant_changed(self, index):
        if self.op1_type.currentText() == "int":
            if self.op1_value is not None:
                self.op1_value.setParent(None)
                self.op1_value = None
            self.op1_value = QtWidgets.QSpinBox()
            self.op1_value.setRange(-2147483648, 2147483647)
            self.gridLayout.addWidget(self.op1_value, 0, 3)
        else:
            if self.op1_value is not None:
                self.op1_value.setParent(None)
                self.op1_value = None
            self.op1_value = QtWidgets.QDoubleSpinBox()
            self.op1_value.setDecimals(6)
            self.op1_value.setRange(-(2 ** 64), 2 ** 64 - 1)
            self.gridLayout.addWidget(self.op1_value, 0, 3)

    def op2_constant_changed(self, index):
        if self.op2_type.currentText() == "int":
            if self.op2_value is not None:
                self.op2_value.setParent(None)
                self.op2_value = None
            self.op2_value = QtWidgets.QSpinBox()
            self.op2_value.setRange(-2147483648, 2147483647)
            self.gridLayout.addWidget(self.op2_value, 2, 3)
        else:
            if self.op2_value is not None:
                self.op2_value.setParent(None)
                self.op2_value = None
            self.op2_value = QtWidgets.QDoubleSpinBox()
            self.op2_value.setDecimals(6)
            self.op2_value.setRange(-(2 ** 64), 2 ** 64 - 1)
            self.gridLayout.addWidget(self.op2_value, 2, 3)

    def apply(self, event):
        if self.operand1.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select operand 1 first",
            )
            return

        if self.operand2.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select operand 2 first",
            )
            return

        if self.op1_type is not None and self.op1_type.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select operand 1 type first",
            )
            return

        if self.op2_type is not None and self.op2_type.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select operand 2 type first",
            )

        if self.op.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select operator",
            )

        operand1 = self.operand1.currentText()
        operand2 = self.operand2.currentText()

        if operand1 == "CONSTANT":
            if self.op1_type.currentText() == "int":
                operand1 = int(self.op1_value.value())
            else:
                operand1 = float(self.op1_value.value())
            operand1_str = str(operand1)
        else:
            operand1 = self.channels[operand1]
            operand1_str = operand1.name

        if operand2 == "CONSTANT":
            if self.op2_type.currentText() == "int":
                operand2 = int(self.op2_value.value())
            else:
                operand2 = float(self.op2_value.value())
            operand2_str = str(operand2)
        else:
            operand2 = self.channels[operand2]
            operand2_str = operand2.name

        op = self.op.currentText().split(" ")[0]

        try:
            self.result = eval(f"operand1 {op} operand2")
            if not hasattr(self.result, "name"):
                self.result = AsamSignal(
                    name="_",
                    samples=np.ones(len(self.all_timebase)) * self.result,
                    timestamps=self.all_timebase,
                )

            name = self.name.text()

            if not name:
                name = f"COMP_{operand1_str}{OPS_TO_STR[op]}{operand2_str}"

            self.result.name = name
            self.result.unit = self.unit.text()
            self.result.enable = True
            self.result.computation = {
                "type": "arithmetic",
                "op": op,
            }

            if isinstance(operand1, (int, float)):
                self.result.computation["operand1"] = operand1
            else:
                if operand1.computed:
                    self.result.computation["operand1"] = operand1.computation
                else:
                    self.result.computation["operand1"] = operand1.name

            if isinstance(operand2, (int, float)):
                self.result.computation["operand2"] = operand2
            else:
                if operand2.computed:
                    self.result.computation["operand2"] = operand2.computation
                else:
                    self.result.computation["operand2"] = operand2.name
        except:
            self.result = None

        self.pressed_button = "apply"
        self.close()

    def function_changed(self, index):
        function = self.function.currentText()
        if function in [
            "arccos",
            "arcsin",
            "arctan",
            "cos",
            "deg2rad",
            "degrees",
            "rad2deg",
            "radians",
            "sin",
            "tan",
            "floor",
            "rint",
            "fix",
            "trunc",
            "cumprod",
            "cumsum",
            "diff",
            "exp",
            "log10",
            "log",
            "log2",
            "absolute",
            "cbrt",
            "sqrt",
            "square",
        ]:
            if self.func_arg1 is not None:
                self.func_arg1.setParent(None)
                self.func_arg1 = None
                self.func_arg2.setParent(None)
                self.func_arg2 = None
        else:
            if self.func_arg1 is None:
                self.func_arg1 = QtWidgets.QDoubleSpinBox()
                self.func_arg1.setDecimals(6)
                self.func_arg1.setRange(-(2 ** 64), 2 ** 64 - 1)
                self.gridLayout_2.addWidget(self.func_arg1, 0, 2)

                self.func_arg2 = QtWidgets.QDoubleSpinBox()
                self.func_arg2.setDecimals(6)
                self.func_arg2.setRange(-(2 ** 64), 2 ** 64 - 1)
                self.gridLayout_2.addWidget(self.func_arg2, 0, 3)

            if function == "round":
                self.func_arg2.setEnabled(False)
            else:
                self.func_arg2.setEnabled(True)

    def apply_function(self, event):
        if self.function.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select a function first",
            )
            return

        if self.channel.currentIndex() == -1:
            QtWidgets.QMessageBox.warning(
                None, "Can't compute new channel", "Must select a channel first",
            )
            return

        function = self.function.currentText()
        channel_name = self.channel.currentText()

        channel = self.channels[channel_name]
        func = getattr(np, function)

        try:

            if function in [
                "arccos",
                "arcsin",
                "arctan",
                "cos",
                "deg2rad",
                "degrees",
                "rad2deg",
                "radians",
                "sin",
                "tan",
                "floor",
                "rint",
                "fix",
                "trunc",
                "cumprod",
                "cumsum",
                "diff",
                "exp",
                "log10",
                "log",
                "log2",
                "absolute",
                "cbrt",
                "sqrt",
                "square",
                "gradient",
            ]:

                samples = func(channel.samples)
                if function == "diff":
                    timestamps = channel.timestamps[1:]
                else:
                    timestamps = channel.timestamps
                name = f"{function}_{channel.name}"
                args = []

            elif function == "around":
                decimals = int(self.func_arg1.value())
                samples = func(channel.samples, decimals)
                timestamps = channel.timestamps
                name = f"{function}_{channel.name}_{decimals}"
                args = [decimals]
            elif function == "clip":
                lower = float(self.func_arg1.value())
                upper = float(self.func_arg2.value())
                samples = func(channel.samples, lower, upper)
                timestamps = channel.timestamps
                name = f"{function}_{channel.name}_{lower}_{upper}"
                args = [lower, upper]

            name = self.function_name.text() or name
            unit = self.function_unit.text() or channel.unit

            self.result = AsamSignal(
                samples=samples, timestamps=timestamps, name=name, unit=unit,
            )
            self.result.enabled = True
            self.result.computation = {
                "type": "function",
                "channel": channel.computation or channel_name,
                "name": function,
                "args": args,
            }

        except Exception as err:
            QtWidgets.QMessageBox.critical(
                None, "Function error", str(err),
            )
            self.result = None

        self.pressed_button = "apply"
        self.close()

    def cancel(self, event):
        self.result = None
        self.pressed_button = "cancel"
        self.close()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'channel_display_widget.ui'
#
# Created by: PyQt5 UI code generator 5.12
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ChannelDiplay(object):
    def setupUi(self, ChannelDiplay):
        ChannelDiplay.setObjectName("ChannelDiplay")
        ChannelDiplay.resize(393, 30)
        ChannelDiplay.setMinimumSize(QtCore.QSize(40, 30))
        self.horizontalLayout = QtWidgets.QHBoxLayout(ChannelDiplay)
        self.horizontalLayout.setContentsMargins(2, 0, 2, 0)
        self.horizontalLayout.setSpacing(2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.display = QtWidgets.QCheckBox(ChannelDiplay)
        self.display.setMinimumSize(QtCore.QSize(13, 13))
        self.display.setText("")
        self.display.setChecked(True)
        self.display.setObjectName("display")
        self.horizontalLayout.addWidget(self.display)
        self.color_btn = QtWidgets.QPushButton(ChannelDiplay)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.color_btn.sizePolicy().hasHeightForWidth())
        self.color_btn.setSizePolicy(sizePolicy)
        self.color_btn.setMinimumSize(QtCore.QSize(13, 13))
        self.color_btn.setMaximumSize(QtCore.QSize(13, 13))
        self.color_btn.setAutoFillBackground(False)
        self.color_btn.setStyleSheet("background-color: rgb(255, 0, 0);")
        self.color_btn.setText("")
        self.color_btn.setFlat(False)
        self.color_btn.setObjectName("color_btn")
        self.horizontalLayout.addWidget(self.color_btn)
        self.name = QtWidgets.QLabel(ChannelDiplay)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.name.sizePolicy().hasHeightForWidth())
        self.name.setSizePolicy(sizePolicy)
        self.name.setMinimumSize(QtCore.QSize(0, 26))
        self.name.setMouseTracking(False)
        self.name.setTextFormat(QtCore.Qt.PlainText)
        self.name.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse)
        self.name.setObjectName("name")
        self.horizontalLayout.addWidget(self.name)
        self.value = QtWidgets.QLabel(ChannelDiplay)
        self.value.setMinimumSize(QtCore.QSize(75, 0))
        self.value.setText("")
        self.value.setTextFormat(QtCore.Qt.PlainText)
        self.value.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.value.setObjectName("value")
        self.horizontalLayout.addWidget(self.value)
        self.ylink = QtWidgets.QCheckBox(ChannelDiplay)
        self.ylink.setText("")
        self.ylink.setObjectName("ylink")
        self.horizontalLayout.addWidget(self.ylink)
        self.individual_axis = QtWidgets.QCheckBox(ChannelDiplay)
        self.individual_axis.setText("")
        self.individual_axis.setObjectName("individual_axis")
        self.horizontalLayout.addWidget(self.individual_axis)
        self.horizontalLayout.setStretch(2, 1)

        self.retranslateUi(ChannelDiplay)
        QtCore.QMetaObject.connectSlotsByName(ChannelDiplay)

    def retranslateUi(self, ChannelDiplay):
        _translate = QtCore.QCoreApplication.translate
        ChannelDiplay.setWindowTitle(_translate("ChannelDiplay", "Form"))
        self.name.setText(_translate("ChannelDiplay", "MAIN CLOCK"))
        self.ylink.setToolTip(_translate("ChannelDiplay", "enable common Y axis"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'd:\DSUsers\uidn3651\02__PythonWorkspace\asammdf\asammdf\gui\ui\channel_stats.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ChannelStats(object):
    def setupUi(self, ChannelStats):
        ChannelStats.setObjectName("ChannelStats")
        ChannelStats.resize(315, 852)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(10)
        ChannelStats.setFont(font)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(ChannelStats)
        self.verticalLayout_2.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_2.setSpacing(2)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.scrollArea = QtWidgets.QScrollArea(ChannelStats)
        self.scrollArea.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 309, 846))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.range_group = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.range_group.setObjectName("range_group")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.range_group)
        self.gridLayout_5.setContentsMargins(4, 4, 4, 4)
        self.gridLayout_5.setSpacing(0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.unit11 = QtWidgets.QLabel(self.range_group)
        self.unit11.setText("")
        self.unit11.setObjectName("unit11")
        self.gridLayout_5.addWidget(self.unit11, 7, 2, 1, 1)
        self.selected_rms = QtWidgets.QLabel(self.range_group)
        self.selected_rms.setText("")
        self.selected_rms.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_rms.setObjectName("selected_rms")
        self.gridLayout_5.addWidget(self.selected_rms, 7, 1, 1, 1)
        self.unit10 = QtWidgets.QLabel(self.range_group)
        self.unit10.setText("")
        self.unit10.setObjectName("unit10")
        self.gridLayout_5.addWidget(self.unit10, 6, 2, 1, 1)
        self.selected_average = QtWidgets.QLabel(self.range_group)
        self.selected_average.setAutoFillBackground(False)
        self.selected_average.setText("")
        self.selected_average.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_average.setObjectName("selected_average")
        self.gridLayout_5.addWidget(self.selected_average, 6, 1, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.range_group)
        self.label_29.setObjectName("label_29")
        self.gridLayout_5.addWidget(self.label_29, 7, 0, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.range_group)
        self.label_15.setObjectName("label_15")
        self.gridLayout_5.addWidget(self.label_15, 1, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.range_group)
        self.label.setObjectName("label")
        self.gridLayout_5.addWidget(self.label, 6, 0, 1, 1)
        self.label_14 = QtWidgets.QLabel(self.range_group)
        self.label_14.setObjectName("label_14")
        self.gridLayout_5.addWidget(self.label_14, 4, 0, 1, 1)
        self.unit2 = QtWidgets.QLabel(self.range_group)
        self.unit2.setText("")
        self.unit2.setObjectName("unit2")
        self.gridLayout_5.addWidget(self.unit2, 4, 2, 1, 1)
        self.unit3 = QtWidgets.QLabel(self.range_group)
        self.unit3.setText("")
        self.unit3.setObjectName("unit3")
        self.gridLayout_5.addWidget(self.unit3, 5, 2, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.range_group)
        self.label_20.setObjectName("label_20")
        self.gridLayout_5.addWidget(self.label_20, 0, 2, 1, 1)
        self.selected_stop = QtWidgets.QLabel(self.range_group)
        self.selected_stop.setText("")
        self.selected_stop.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_stop.setObjectName("selected_stop")
        self.gridLayout_5.addWidget(self.selected_stop, 1, 1, 1, 1)
        self.selected_start = QtWidgets.QLabel(self.range_group)
        self.selected_start.setText("")
        self.selected_start.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_start.setObjectName("selected_start")
        self.gridLayout_5.addWidget(self.selected_start, 0, 1, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.range_group)
        self.label_18.setObjectName("label_18")
        self.gridLayout_5.addWidget(self.label_18, 8, 0, 1, 1)
        self.selected_max = QtWidgets.QLabel(self.range_group)
        self.selected_max.setText("")
        self.selected_max.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_max.setObjectName("selected_max")
        self.gridLayout_5.addWidget(self.selected_max, 5, 1, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.range_group)
        self.label_23.setObjectName("label_23")
        self.gridLayout_5.addWidget(self.label_23, 3, 2, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.range_group)
        self.label_22.setObjectName("label_22")
        self.gridLayout_5.addWidget(self.label_22, 1, 2, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.range_group)
        self.label_17.setObjectName("label_17")
        self.gridLayout_5.addWidget(self.label_17, 5, 0, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.range_group)
        self.label_13.setObjectName("label_13")
        self.gridLayout_5.addWidget(self.label_13, 0, 0, 1, 1)
        self.label_21 = QtWidgets.QLabel(self.range_group)
        self.label_21.setObjectName("label_21")
        self.gridLayout_5.addWidget(self.label_21, 3, 0, 1, 1)
        self.unit4 = QtWidgets.QLabel(self.range_group)
        self.unit4.setText("")
        self.unit4.setObjectName("unit4")
        self.gridLayout_5.addWidget(self.unit4, 8, 2, 1, 1)
        self.selected_min = QtWidgets.QLabel(self.range_group)
        self.selected_min.setText("")
        self.selected_min.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_min.setObjectName("selected_min")
        self.gridLayout_5.addWidget(self.selected_min, 4, 1, 1, 1)
        self.selected_delta_t = QtWidgets.QLabel(self.range_group)
        self.selected_delta_t.setText("")
        self.selected_delta_t.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_delta_t.setObjectName("selected_delta_t")
        self.gridLayout_5.addWidget(self.selected_delta_t, 3, 1, 1, 1)
        self.selected_delta = QtWidgets.QLabel(self.range_group)
        self.selected_delta.setText("")
        self.selected_delta.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.selected_delta.setObjectName("selected_delta")
        self.gridLayout_5.addWidget(self.selected_delta, 8, 1, 1, 1)
        self.gridLayout_5.setColumnStretch(1, 1)
        self.gridLayout.addWidget(self.range_group, 2, 0, 1, 2)
        self.overall_group = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.overall_group.setObjectName("overall_group")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.overall_group)
        self.gridLayout_2.setContentsMargins(4, 4, 4, 4)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_32 = QtWidgets.QLabel(self.overall_group)
        self.label_32.setObjectName("label_32")
        self.gridLayout_2.addWidget(self.label_32, 5, 0, 1, 1)
        self.unit14 = QtWidgets.QLabel(self.overall_group)
        self.unit14.setText("")
        self.unit14.setObjectName("unit14")
        self.gridLayout_2.addWidget(self.unit14, 5, 2, 1, 1)
        self.unit15 = QtWidgets.QLabel(self.overall_group)
        self.unit15.setText("")
        self.unit15.setObjectName("unit15")
        self.gridLayout_2.addWidget(self.unit15, 6, 2, 1, 1)
        self.overall_rms = QtWidgets.QLabel(self.overall_group)
        self.overall_rms.setText("")
        self.overall_rms.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_rms.setObjectName("overall_rms")
        self.gridLayout_2.addWidget(self.overall_rms, 6, 1, 1, 1)
        self.overall_min = QtWidgets.QLabel(self.overall_group)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overall_min.sizePolicy().hasHeightForWidth())
        self.overall_min.setSizePolicy(sizePolicy)
        self.overall_min.setText("")
        self.overall_min.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_min.setObjectName("overall_min")
        self.gridLayout_2.addWidget(self.overall_min, 3, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.overall_group)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 0, 1, 1)
        self.label_27 = QtWidgets.QLabel(self.overall_group)
        self.label_27.setObjectName("label_27")
        self.gridLayout_2.addWidget(self.label_27, 0, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.overall_group)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_28 = QtWidgets.QLabel(self.overall_group)
        self.label_28.setObjectName("label_28")
        self.gridLayout_2.addWidget(self.label_28, 1, 2, 1, 1)
        self.unit9 = QtWidgets.QLabel(self.overall_group)
        self.unit9.setText("")
        self.unit9.setObjectName("unit9")
        self.gridLayout_2.addWidget(self.unit9, 4, 2, 1, 1)
        self.overall_max = QtWidgets.QLabel(self.overall_group)
        self.overall_max.setText("")
        self.overall_max.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_max.setObjectName("overall_max")
        self.gridLayout_2.addWidget(self.overall_max, 4, 1, 1, 1)
        self.overall_start = QtWidgets.QLabel(self.overall_group)
        self.overall_start.setText("")
        self.overall_start.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_start.setObjectName("overall_start")
        self.gridLayout_2.addWidget(self.overall_start, 0, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.overall_group)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 4, 0, 1, 1)
        self.label_33 = QtWidgets.QLabel(self.overall_group)
        self.label_33.setObjectName("label_33")
        self.gridLayout_2.addWidget(self.label_33, 6, 0, 1, 1)
        self.overall_average = QtWidgets.QLabel(self.overall_group)
        self.overall_average.setText("")
        self.overall_average.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_average.setObjectName("overall_average")
        self.gridLayout_2.addWidget(self.overall_average, 5, 1, 1, 1)
        self.overall_stop = QtWidgets.QLabel(self.overall_group)
        self.overall_stop.setText("")
        self.overall_stop.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.overall_stop.setObjectName("overall_stop")
        self.gridLayout_2.addWidget(self.overall_stop, 1, 1, 1, 1)
        self.unit8 = QtWidgets.QLabel(self.overall_group)
        self.unit8.setText("")
        self.unit8.setObjectName("unit8")
        self.gridLayout_2.addWidget(self.unit8, 3, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.overall_group)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 3, 0, 1, 1)
        self.gridLayout_2.setColumnStretch(1, 1)
        self.gridLayout.addWidget(self.overall_group, 4, 0, 1, 2)
        self.name = QtWidgets.QTextEdit(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.name.sizePolicy().hasHeightForWidth())
        self.name.setSizePolicy(sizePolicy)
        self.name.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.name.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.name.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.name.setReadOnly(True)
        self.name.setObjectName("name")
        self.gridLayout.addWidget(self.name, 0, 0, 1, 2)
        self.cursor_group = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.cursor_group.setFlat(False)
        self.cursor_group.setCheckable(False)
        self.cursor_group.setObjectName("cursor_group")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.cursor_group)
        self.gridLayout_4.setContentsMargins(4, 4, 4, 4)
        self.gridLayout_4.setSpacing(0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.cursor_t = QtWidgets.QLabel(self.cursor_group)
        self.cursor_t.setText("")
        self.cursor_t.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.cursor_t.setObjectName("cursor_t")
        self.gridLayout_4.addWidget(self.cursor_t, 0, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.cursor_group)
        self.label_12.setObjectName("label_12")
        self.gridLayout_4.addWidget(self.label_12, 0, 0, 1, 1)
        self.cursor_value = QtWidgets.QLabel(self.cursor_group)
        self.cursor_value.setText("")
        self.cursor_value.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.cursor_value.setObjectName("cursor_value")
        self.gridLayout_4.addWidget(self.cursor_value, 1, 1, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.cursor_group)
        self.label_11.setObjectName("label_11")
        self.gridLayout_4.addWidget(self.label_11, 1, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.cursor_group)
        self.label_2.setObjectName("label_2")
        self.gridLayout_4.addWidget(self.label_2, 0, 2, 1, 1)
        self.unit1 = QtWidgets.QLabel(self.cursor_group)
        self.unit1.setText("")
        self.unit1.setObjectName("unit1")
        self.gridLayout_4.addWidget(self.unit1, 1, 2, 1, 1)
        self.gridLayout_4.setColumnStretch(1, 1)
        self.gridLayout.addWidget(self.cursor_group, 1, 0, 1, 2)
        self.visible_group = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.visible_group.setObjectName("visible_group")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.visible_group)
        self.gridLayout_3.setContentsMargins(4, 4, 4, 4)
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_25 = QtWidgets.QLabel(self.visible_group)
        self.label_25.setObjectName("label_25")
        self.gridLayout_3.addWidget(self.label_25, 1, 2, 1, 1)
        self.label_26 = QtWidgets.QLabel(self.visible_group)
        self.label_26.setObjectName("label_26")
        self.gridLayout_3.addWidget(self.label_26, 2, 2, 1, 1)
        self.unit5 = QtWidgets.QLabel(self.visible_group)
        self.unit5.setText("")
        self.unit5.setObjectName("unit5")
        self.gridLayout_3.addWidget(self.unit5, 3, 2, 1, 1)
        self.unit6 = QtWidgets.QLabel(self.visible_group)
        self.unit6.setText("")
        self.unit6.setObjectName("unit6")
        self.gridLayout_3.addWidget(self.unit6, 4, 2, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.visible_group)
        self.label_24.setObjectName("label_24")
        self.gridLayout_3.addWidget(self.label_24, 0, 2, 1, 1)
        self.visible_start = QtWidgets.QLabel(self.visible_group)
        self.visible_start.setText("")
        self.visible_start.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_start.setObjectName("visible_start")
        self.gridLayout_3.addWidget(self.visible_start, 0, 1, 1, 1)
        self.visible_stop = QtWidgets.QLabel(self.visible_group)
        self.visible_stop.setText("")
        self.visible_stop.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_stop.setObjectName("visible_stop")
        self.gridLayout_3.addWidget(self.visible_stop, 1, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.visible_group)
        self.label_10.setObjectName("label_10")
        self.gridLayout_3.addWidget(self.label_10, 4, 0, 1, 1)
        self.visible_delta_t = QtWidgets.QLabel(self.visible_group)
        self.visible_delta_t.setText("")
        self.visible_delta_t.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_delta_t.setObjectName("visible_delta_t")
        self.gridLayout_3.addWidget(self.visible_delta_t, 2, 1, 1, 1)
        self.visible_max = QtWidgets.QLabel(self.visible_group)
        self.visible_max.setText("")
        self.visible_max.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_max.setObjectName("visible_max")
        self.gridLayout_3.addWidget(self.visible_max, 4, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.visible_group)
        self.label_9.setObjectName("label_9")
        self.gridLayout_3.addWidget(self.label_9, 3, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.visible_group)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 0, 0, 1, 1)
        self.unit7 = QtWidgets.QLabel(self.visible_group)
        self.unit7.setText("")
        self.unit7.setObjectName("unit7")
        self.gridLayout_3.addWidget(self.unit7, 7, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.visible_group)
        self.label_19.setObjectName("label_19")
        self.gridLayout_3.addWidget(self.label_19, 7, 0, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.visible_group)
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 2, 0, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.visible_group)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 1, 0, 1, 1)
        self.visible_delta = QtWidgets.QLabel(self.visible_group)
        self.visible_delta.setText("")
        self.visible_delta.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_delta.setObjectName("visible_delta")
        self.gridLayout_3.addWidget(self.visible_delta, 7, 1, 1, 1)
        self.visible_min = QtWidgets.QLabel(self.visible_group)
        self.visible_min.setText("")
        self.visible_min.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_min.setObjectName("visible_min")
        self.gridLayout_3.addWidget(self.visible_min, 3, 1, 1, 1)
        self.label_30 = QtWidgets.QLabel(self.visible_group)
        self.label_30.setObjectName("label_30")
        self.gridLayout_3.addWidget(self.label_30, 5, 0, 1, 1)
        self.label_31 = QtWidgets.QLabel(self.visible_group)
        self.label_31.setObjectName("label_31")
        self.gridLayout_3.addWidget(self.label_31, 6, 0, 1, 1)
        self.visible_average = QtWidgets.QLabel(self.visible_group)
        self.visible_average.setText("")
        self.visible_average.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_average.setObjectName("visible_average")
        self.gridLayout_3.addWidget(self.visible_average, 5, 1, 1, 1)
        self.visible_rms = QtWidgets.QLabel(self.visible_group)
        self.visible_rms.setText("")
        self.visible_rms.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.visible_rms.setObjectName("visible_rms")
        self.gridLayout_3.addWidget(self.visible_rms, 6, 1, 1, 1)
        self.unit12 = QtWidgets.QLabel(self.visible_group)
        self.unit12.setText("")
        self.unit12.setObjectName("unit12")
        self.gridLayout_3.addWidget(self.unit12, 5, 2, 1, 1)
        self.unit13 = QtWidgets.QLabel(self.visible_group)
        self.unit13.setText("")
        self.unit13.setObjectName("unit13")
        self.gridLayout_3.addWidget(self.unit13, 6, 2, 1, 1)
        self.gridLayout_3.setColumnStretch(1, 1)
        self.gridLayout.addWidget(self.visible_group, 3, 0, 1, 2)
        self.gridLayout.setRowStretch(0, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        spacerItem = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout.addItem(spacerItem)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_2.addWidget(self.scrollArea)

        self.retranslateUi(ChannelStats)
        QtCore.QMetaObject.connectSlotsByName(ChannelStats)

    def retranslateUi(self, ChannelStats):
        _translate = QtCore.QCoreApplication.translate
        ChannelStats.setWindowTitle(_translate("ChannelStats", "Form"))
        self.range_group.setTitle(_translate("ChannelStats", "Selected range"))
        self.label_29.setText(_translate("ChannelStats", "RMS"))
        self.label_15.setText(_translate("ChannelStats", "Last timestamp"))
        self.label.setText(_translate("ChannelStats", "Average"))
        self.label_14.setText(_translate("ChannelStats", "Min"))
        self.label_20.setText(_translate("ChannelStats", " s"))
        self.label_18.setText(_translate("ChannelStats", "Δ"))
        self.label_23.setText(_translate("ChannelStats", " s"))
        self.label_22.setText(_translate("ChannelStats", " s"))
        self.label_17.setText(_translate("ChannelStats", "Max"))
        self.label_13.setText(_translate("ChannelStats", "First timestamp"))
        self.label_21.setText(_translate("ChannelStats", "Δt"))
        self.overall_group.setTitle(_translate("ChannelStats", "Overall"))
        self.label_32.setText(_translate("ChannelStats", "Average"))
        self.label_3.setText(_translate("ChannelStats", "First timestamp"))
        self.label_27.setText(_translate("ChannelStats", " s"))
        self.label_4.setText(_translate("ChannelStats", "Last timestamp"))
        self.label_28.setText(_translate("ChannelStats", " s"))
        self.label_6.setText(_translate("ChannelStats", "Max"))
        self.label_33.setText(_translate("ChannelStats", "RMS"))
        self.label_5.setText(_translate("ChannelStats", "Min"))
        self.name.setHtml(
            _translate(
                "ChannelStats",
                '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "http://www.w3.org/TR/REC-html40/strict.dtd">\n'
                '<html><head><meta name="qrichtext" content="1" /><style type="text/css">\n'
                "p, li { white-space: pre-wrap; }\n"
                "</style></head><body style=\" font-family:'Consolas'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
                '<p style="-qt-paragraph-type:empty; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><br /></p></body></html>',
            )
        )
        self.cursor_group.setTitle(_translate("ChannelStats", "Cursor"))
        self.label_12.setText(_translate("ChannelStats", "Timestamp      "))
        self.label_11.setText(_translate("ChannelStats", "Value"))
        self.label_2.setText(_translate("ChannelStats", " s"))
        self.visible_group.setTitle(_translate("ChannelStats", "Visible range"))
        self.label_25.setText(_translate("ChannelStats", " s"))
        self.label_26.setText(_translate("ChannelStats", " s"))
        self.label_24.setText(_translate("ChannelStats", " s"))
        self.label_10.setText(_translate("ChannelStats", "Max"))
        self.label_9.setText(_translate("ChannelStats", "Min"))
        self.label_7.setText(_translate("ChannelStats", "First timestamp"))
        self.label_19.setText(_translate("ChannelStats", "Δ"))
        self.label_16.setText(_translate("ChannelStats", "Δt"))
        self.label_8.setText(_translate("ChannelStats", "Last timestamp"))
        self.label_30.setText(_translate("ChannelStats", "Average"))
        self.label_31.setText(_translate("ChannelStats", "RMS"))



"""
asammdf

"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages, Extension
from distutils.core import setup, Extension

from distutils.command import build_ext


def get_export_symbols(self, ext):
    parts = ext.name.split(".")
    print("parts", parts)
    if parts[-1] == "__init__":
        initfunc_name = "PyInit_" + parts[-2]
    else:
        initfunc_name = "PyInit_" + parts[-1]


build_ext.build_ext.get_export_symbols = get_export_symbols


def get_export_symbols(self, ext):
    parts = ext.name.split(".")
    print("parts", parts)
    if parts[-1] == "__init__":
        initfunc_name = "PyInit_" + parts[-2]
    else:
        initfunc_name = "PyInit_" + parts[-1]


build_ext.build_ext.get_export_symbols = get_export_symbols
# To use a consistent encoding
from codecs import open
from os import path, listdir, walk

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
long_description = open("README.md", "rb").read().decode("utf-8")

with open(path.join("asammdf", "version.py"), "r") as f:
    for line in f:
        if line.startswith("__version__"):
            version = line.split("=")[-1].strip().strip('"')
            break

try:
    try:
        import numpy
    except ImportError:
        print(
            "numpy must be preinstalled to compile the asammdf C extension; falling back to pure python"
        )
    setup(
        name="asammdf",
        # Versions should comply with PEP440.  For a discussion on single-sourcing
        # the version across setup.py and the project code, see
        # https://packaging.python.org/en/latest/single_source_version.html
        version=version,
        description="ASAM MDF measurement data file parser",
        long_description=long_description,
        long_description_content_type=r"text/markdown",
        # The project's main homepage.
        url="https://github.com/danielhrisca/asammdf",
        # Author details
        author="Daniel Hrisca",
        author_email="daniel.hrisca@gmail.com",
        # Choose your license
        license="LGPLv3+",
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        classifiers=[
            # How mature is this project? Common values are
            #   3 - Alpha
            #   4 - Beta
            #   5 - Production/Stable
            "Development Status :: 4 - Beta",
            # Indicate who your project is intended for
            "Intended Audience :: Developers",
            "Topic :: Software Development",
            "Topic :: Scientific/Engineering",
            # Pick your license as you wish (should match "license" above)
            "License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
            # Specify the Python versions you support here. In particular, ensure
            # that you indicate whether you support Python 2, Python 3 or both.
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
        ],
        # What does your project relate to?
        keywords="read reader edit editor parse parser asam mdf measurement",
        # You can just specify the packages manually here if your project is
        # simple. Or you can use find_packages().
        packages=find_packages(exclude=["contrib", "docs", "test"]),
        # Alternatively, if you want to distribute just a my_module.py, uncomment
        # this:
        #   py_modules=["my_module"],
        # List run-time dependencies here.  These will be installed by pip when
        # your project is installed. For an analysis of "install_requires" vs pip's
        # requirements files see:
        # https://packaging.python.org/en/latest/requirements.html
        install_requires=[
            "numpy>=1.16.1",
            "pandas",
            "numexpr",
            "wheel",
            "canmatrix~=0.8",
            "natsort",
            "lxml",
            "cChardet",
        ],
        # List additional groups of dependencies here (e.g. development
        # dependencies). You can install these using the following syntax,
        # for example:
        # $ pip install -e .[dev,test]
        extras_require={"gui": ["PyQt5>=5.13.1", "pyqtgraph>=0.10.0", "psutil"],},
        # If there are data files included in your packages that need to be
        # installed, specify them here.  If using Python 2.6 or less, then these
        # have to be included in MANIFEST.in as well.
        package_data={"asammdf": ["asammdf/gui/ui/*.ui"]},
        include_package_data=True,
        # Although 'package_data' is the preferred approach, in some case you may
        # need to place data files outside of your packages. See:
        # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
        # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
        #    data_files=[('my_data', ['data/data_file'])],
        # To provide executable scripts, use entry points in preference to the
        # "scripts" keyword. Entry points provide cross-platform support and allow
        # pip to create the appropriate form of executable for the target platform.
        entry_points={"console_scripts": ["asammdf=asammdf.gui.asammdfgui:main",],},
        ext_package="asammdf.blocks",
        ext_modules=[
            Extension(
                "cutils",
                ["asammdf/blocks/cutils.c"],
                include_dirs=[numpy.get_include()],
            )
        ],
    )

except:
    setup(
        name="asammdf",
        # Versions should comply with PEP440.  For a discussion on single-sourcing
        # the version across setup.py and the project code, see
        # https://packaging.python.org/en/latest/single_source_version.html
        version=version,
        description="ASAM MDF measurement data file parser",
        long_description=long_description,
        long_description_content_type=r"text/markdown",
        # The project's main homepage.
        url="https://github.com/danielhrisca/asammdf",
        # Author details
        author="Daniel Hrisca",
        author_email="daniel.hrisca@gmail.com",
        # Choose your license
        license="LGPLv3+",
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        classifiers=[
            # How mature is this project? Common values are
            #   3 - Alpha
            #   4 - Beta
            #   5 - Production/Stable
            "Development Status :: 4 - Beta",
            # Indicate who your project is intended for
            "Intended Audience :: Developers",
            "Topic :: Software Development",
            "Topic :: Scientific/Engineering",
            # Pick your license as you wish (should match "license" above)
            "License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
            # Specify the Python versions you support here. In particular, ensure
            # that you indicate whether you support Python 2, Python 3 or both.
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
        ],
        # What does your project relate to?
        keywords="read reader edit editor parse parser asam mdf measurement",
        # You can just specify the packages manually here if your project is
        # simple. Or you can use find_packages().
        packages=find_packages(exclude=["contrib", "docs", "test"]),
        # Alternatively, if you want to distribute just a my_module.py, uncomment
        # this:
        #   py_modules=["my_module"],
        # List run-time dependencies here.  These will be installed by pip when
        # your project is installed. For an analysis of "install_requires" vs pip's
        # requirements files see:
        # https://packaging.python.org/en/latest/requirements.html
        install_requires=[
            "numpy>=1.16.1",
            "pandas",
            "numexpr",
            "wheel",
            "canmatrix>=0.8",
            "natsort",
            "lxml",
            "cChardet",
        ],
        # List additional groups of dependencies here (e.g. development
        # dependencies). You can install these using the following syntax,
        # for example:
        # $ pip install -e .[dev,test]
        extras_require={"gui": ["PyQt5>=5.13.1", "pyqtgraph>=0.10.0", "psutil"],},
        # If there are data files included in your packages that need to be
        # installed, specify them here.  If using Python 2.6 or less, then these
        # have to be included in MANIFEST.in as well.
        package_data={"asammdf": ["asammdf/gui/ui/*.ui"]},
        include_package_data=True,
        # Although 'package_data' is the preferred approach, in some case you may
        # need to place data files outside of your packages. See:
        # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
        # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
        #    data_files=[('my_data', ['data/data_file'])],
        # To provide executable scripts, use entry points in preference to the
        # "scripts" keyword. Entry points provide cross-platform support and allow
        # pip to create the appropriate form of executable for the target platform.
        entry_points={"console_scripts": ["asammdf=asammdf.gui.asammdfgui:main",],},
    )
